package VMOMI::ClusterVmReadinessReadyCondition;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
